import 'package:alghwalbi_easy_router/src/helpers/animation_helper.dart';
import 'package:alghwalbi_easy_router/src/helpers/layout_helper.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';

enum MessageType {
  none,
  success,
  error,
  warning,
  info,
  custom,
}

class NavigatorHelper {
  static void defaultShowInvalidRouterDialog(BuildContext context) {
    showDialog(
      context: context,
      builder: (BuildContext context) {
        return AlertDialog(
          title: const Text('Invalid Router'),
          content: const Text('The router you provided is invalid.'),
          actions: <Widget>[
            TextButton(
              onPressed: () {
                Navigator.of(context).pop();
              },
              child: const Text('OK'),
            ),
          ],
        );
      },
    );
  }

  static Future<dynamic> navigateTo(
      BuildContext context, Widget Function() creator,
      {bool replacment = false,
      bool replaceAll = false,
      AnimationTypes animationType = AnimationTypes.none}) {
    if (kIsWeb || LayoutHelper.disableAnimation(context)) {
      animationType = AnimationTypes.none;
    }

    PageRoute route;
    if (Theme.of(context).platform == TargetPlatform.iOS &&
        animationType != AnimationTypes.opacity) {
      route = CupertinoPageRoute(builder: (_) => creator());
    } else if (animationType == AnimationTypes.none) {
      route = PageRouteBuilder(pageBuilder: (_, __, ___) => creator());
    } else {
      route = PageRouteBuilder(
          pageBuilder: (_, __, ___) => creator(),
          transitionDuration: Duration(
              milliseconds:
                  animationType == AnimationTypes.opacity ? 400 : 300), //300
          transitionsBuilder: AnimationHelper.getAnimation(animationType));
    }
    if (replaceAll) {
      // remove all pages in navigation history
      while (Navigator.of(context).canPop()) {
        Navigator.of(context).pop();
      }
      replacment = true;
      //return Navigator.of(context).pushAndRemoveUntil(route,(Route<dynamic> route) => route.isFirst);
    }

    if (replacment) {
      return Navigator.of(context).pushReplacement(route);
    } else {
      return Navigator.of(context).push(route);
    }
  }
}
